@@ -635,6 +635,111 @@ class HandProjects():
                     
             cv2.imshow("WebCam", img)
             cv2.waitKey(1)
+    def Virtual_Painter(folderName,Confidence=0.65,BrushThickness=25,EraserThickness=100,WebCam=0):
+        folderPath = folderName
+        myList = os.listdir(folderPath)
+        #print(myList)
+        overlayList = []
+        for imPath in myList:
+            image = cv2.imread(f'{folderPath}/{imPath}')
+            overlayList.append(image)
+        #print(len(overlayList))
+        header = overlayList[0]
+        ##File path get done
+        drawColor = (255,0,255)
+
+        cap = cv2.VideoCapture(WebCam)
+        cap.set(3,1280)
+        cap.set(4,720)
+
+        xp, yp = 0,0
+        detector = htm.handDetector(detectionCon=Confidence)
+
+        brushThickness = BrushThickness
+        eraserThickness = EraserThickness
+
+        imgCanvas = np.zeros((720, 1280, 3),np.uint8)
+
+        while True:
+            success,img = cap.read()
+            img = cv2.flip(img,1)
+            #img = cv2.flip(img, 1)
+
+            img = detector.findHands(img)
+            lmList = detector.findPosition(img,draw=False)
+
+            if len(lmList) != 0:
+                #print(lmList)
+                    
+                x1,y1 = lmList[8][1:]
+                x2,y2 = lmList[12][1:]
+            
+                fingers = detector.fingersUp()
+                #print(fingers)
+
+                if fingers[1] and fingers[2] :
+                    xp, yp = 0,0
+                    #print("Selection Mode")
+                    if y1 <120:
+                        if 90<x1<110:
+                            header = overlayList[0]
+                            drawColor = (255,0,255)
+                        elif 220<x1<240:
+                            header = overlayList[1]
+                            drawColor = (240,28,28)
+                        elif 350<x1<380:
+                            header = overlayList[2]
+                            drawColor = (0,255,0)
+                        elif 460<x1<510:
+                            header = overlayList[3]
+                            ##(173,216,230)
+                            drawColor = (230,216,173)
+                        elif 570<x1<610:
+                            header = overlayList[4]
+                            drawColor = (0,0,255)
+                        elif 700<x1<750:
+                            header = overlayList[5]
+                            drawColor = (0,165,255)
+                        elif 790<x1<850:
+                            header = overlayList[6]
+                            drawColor = (0,255,255)
+                        elif 1000<x1<1100:
+                            header = overlayList[7]
+                            drawColor = (0,0,0)
+                    cv2.rectangle(img,(x1,y1-25),(x2,y2+25),drawColor,cv2.FILLED)
+                    
+
+                if fingers[1] and fingers[2]==False and fingers[3]==False and fingers[0]==False and fingers[4]==False:
+                    #print("Drawing Mode")
+                    cv2.circle(img, (x1,y1),brushThickness,drawColor,cv2.FILLED)
+
+                    if xp==0 and yp==0:
+                        xp,yp = x1,y1
+                    if drawColor == (0,0,0):
+                        cv2.line(img, (xp,yp),(x1,y1),drawColor,eraserThickness)
+                        cv2.line(imgCanvas, (xp,yp),(x1,y1),drawColor,eraserThickness)
+                    else:
+                        cv2.line(img, (xp,yp),(x1,y1),drawColor,brushThickness)
+                        cv2.line(imgCanvas, (xp,yp),(x1,y1),drawColor,brushThickness)
+
+                    xp,yp = x1,y1
+                        
+
+            imgGray = cv2.cvtColor(imgCanvas,cv2.COLOR_BGR2GRAY)
+            _, imgInv = cv2.threshold(imgGray,50,255,cv2.THRESH_BINARY_INV)
+            imgInv = cv2.cvtColor(imgInv,cv2.COLOR_GRAY2BGR)
+            img = cv2.bitwise_and(img,imgInv)
+            img = cv2.bitwise_or(img,imgCanvas)
+            
+            ######setting header
+            img[0:120,0:1280] = header
+            #img = cv2.addWeighted(img,0.5,imgCanvas,0.5,0)
+            cv2.imshow("Image",img)
+            #cv2.imshow("Canvas",imgCanvas)
+            #cv2.imshow("Inv",img)
+
+            cv2.waitKey(1)
+
     def Virtual_Painter_b_g_r(folder):
         #vars
         brushThickness = 20
